import React, { useState, useEffect, useRef } from 'react';
import ReactDOM from 'react-dom';
import {
  json,
  scaleLinear,
  max,
  min,
  scaleTime,
  timeParse,
  timeFormat,
  line,
  select,
  axisLeft,
  axisBottom
} from 'd3';
const width = 960;
const height = 500;
const margin = {
  left:60,
  top: 50,
  right: 20,
  bottom: 50,
};




const App = () => {
  const [data, setData] = useState(null);
  const svgRef = useRef();
  const parseTime = timeParse('%d %b %y');
	 let tooltip2 = select("body").append("div")
    .attr("class", "tooltip2")
    .style("opacity", 0);

  const formatTime = timeFormat('%b-%y');
  const formatTooltipTime = timeFormat('%B-%Y');
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;
  useEffect(() => {
    json('data.json').then((data) => {
      let cleanData = [];
      console.log(data);
      setData(cleanData);
    });
  }, []);
  
  useEffect(()=>{
    const svg = select(svgRef.current);
    const bar = svg.attr("width", width)
    		.attr("height", height)
      	.append("g")
    		.attr("transform",`translate(${margin.left},${margin.top})`);
    
        
    if(data){

      let listofDate = [];
      
      const xValue = d => d.middle_date;
      const yValue = d => d.data_value;

      const xScale = scaleTime()
    		.domain([min_date, max_date])
    		.range([0, innerWidth])
      
    	const yScale = scaleLinear()
   	 		.domain([0, max(data, (d) => d.data_value)])
    		.range([innerHeight, 0]);
     
      bar.append("g")
      	.attr("class","axis")
        .call(axisLeft(yScale));
			
      bar.append("g")
      .attr("transform",`translate(0, ${innerHeight})`)
      	.attr("class","axis")
  			.call(axisBottom(xScale).tickFormat(tick => formatTime(tick)))
      	
      
      bar.selectAll("mybar")
      .data(data)
      .enter()
      .append("rect")
        .attr("x", d => xScale(d.start_date))
        .attr("y", d => yScale(yValue(d)))
        .attr("width", d => xScale(d.end_date) - xScale(d.start_date))
        .attr("height", d => yScale(0) - yScale(yValue(d)))
        .attr("fill", "rgba(142,209,26,.5)")
      	.on('mouseover', (i,d) => {
        			tooltip2.transition().duration(500).style("opacity", 1);
              tooltip2.html(`${d.timeperiod}:${yValue(d)}</br>start date:${formatTooltipTime(d.start_date)}</br>end date:${formatTooltipTime(d.end_date)}</div>`)
          		.style("left", xScale(d.middle_date) + "px")
          		.style("top", yScale(yValue(d))+"px");
              })
     .on('mouseout', ()=>{tooltip2.transition().duration(500).style("opacity", 0)});
  
    }
      
  },[data])

  if (!data) {
    return <pre>Loading...</pre>;
  }
   
  
  return (
    <svg ref = {svgRef}></svg>
  ); 
};

ReactDOM.render(<App />, document.getElementById('root'));
